searchNodes=[{"ref":"CPF.html","title":"CPF","type":"module","doc":"CPF module that provides functions to verify if a CPF is valid."},{"ref":"CPF.html#digits/1","title":"CPF.digits/1","type":"function","doc":"Returns a tuple with the eleven digits of the given cpf."},{"ref":"CPF.html#format/1","title":"CPF.format/1","type":"function","doc":"Returns a formatted string from a given cpf. Examples iex&gt; 563_606_676_73 |&gt; CPF.new() |&gt; CPF.format() &quot;563.606.676-73&quot;"},{"ref":"CPF.html#new/1","title":"CPF.new/1","type":"function","doc":"Initializes a CPF. Examples iex&gt; CPF.new(563_606_676_73) #CPF&lt;563.606.676-73&gt; iex&gt; CPF.new(&quot;56360667673&quot;) #CPF&lt;563.606.676-73&gt; This function doesn&#39;t check if CPF numbers are valid, only use this function if the given String.t or the integer was validated before."},{"ref":"CPF.html#parse/1","title":"CPF.parse/1","type":"function","doc":"Builds a CPF struct by validating its digits and format. Returns an ok/error tuple for valid/invalid CPFs. Examples iex&gt; {:ok, cpf} = CPF.parse(563_606_676_73) iex&gt; cpf #CPF&lt;563.606.676-73&gt; iex&gt; CPF.parse(563_606_676_72) {:error, %CPF.ParsingError{reason: :invalid_verifier}}"},{"ref":"CPF.html#parse!/1","title":"CPF.parse!/1","type":"function","doc":"Builds a CPF struct by validating its digits and format. Returns an CPF type or raises an CPF.ParsingError exception. Examples iex&gt; CPF.parse!(563_606_676_73) #CPF&lt;563.606.676-73&gt; iex&gt; CPF.parse!(563_606_676_72) ** (CPF.ParsingError) invalid_verifier"},{"ref":"CPF.html#to_integer/1","title":"CPF.to_integer/1","type":"function","doc":"Returns a integer representation of the given cpf. Examples iex&gt; 4_485_847_608 |&gt; CPF.new() |&gt; CPF.to_integer() 4_485_847_608"},{"ref":"CPF.html#valid?/1","title":"CPF.valid?/1","type":"function","doc":"Returns true the given cpf is valid, otherwise false. Examples iex&gt; CPF.valid?(563_606_676_73) true iex&gt; CPF.valid?(563_606_676_72) false iex&gt; CPF.valid?(&quot;563.606.676-73&quot;) true iex&gt; CPF.valid?(&quot;563/60.6-676/73&quot;) false iex&gt; CPF.valid?(&quot;563.606.676-72&quot;) false iex&gt; CPF.valid?(&quot;56360667673&quot;) true iex&gt; CPF.valid?(&quot;56360667672&quot;) false"},{"ref":"CPF.html#t:t/0","title":"CPF.t/0","type":"opaque","doc":"The CPF type. It&#39; composed of eleven digits(0-9])."},{"ref":"CPF.CastingError.html","title":"CPF.CastingError","type":"exception","doc":""},{"ref":"CPF.CastingError.html#message/1","title":"CPF.CastingError.message/1","type":"function","doc":"Callback implementation for Exception.message/1."},{"ref":"CPF.CastingError.html#t:t/0","title":"CPF.CastingError.t/0","type":"type","doc":""},{"ref":"CPF.ParsingError.html","title":"CPF.ParsingError","type":"exception","doc":""},{"ref":"CPF.ParsingError.html#message/1","title":"CPF.ParsingError.message/1","type":"function","doc":"Callback implementation for Exception.message/1."},{"ref":"CPF.ParsingError.html#t:t/0","title":"CPF.ParsingError.t/0","type":"type","doc":""},{"ref":"readme.html","title":"CPF","type":"extras","doc":"CPF A library to work with CPFs. CPF is an acronym for &quot;Cadastro de Pessoa Físicas,&quot; it&#39;s a unique number associated to a person that the Brazilian government maintains. With this number, it is possible to check or retrieve information about a person. This library provides a validation that checks if the number is a valid CPF number. The CPF has check digit algorithm is similar to ISBN 10, you can check the details in Portuguese here."},{"ref":"readme.html#installation","title":"CPF - Installation","type":"extras","doc":"If available in Hex, the package can be installed by adding cpf to your list of dependencies in mix.exs: def deps do [ {:cpf, &quot;~&gt; 0.5&quot;} ] end"},{"ref":"readme.html#quick-start","title":"CPF - Quick Start","type":"extras","doc":"You verify if the CPF is valid by calling the function CPF.valid?/1: iex&gt; CPF.valid?(563_606_676_73) true iex&gt; CPF.valid?(563_606_676_72) false iex&gt; CPF.valid?(&quot;563.606.676-73&quot;) true iex&gt; CPF.valid?(&quot;563.606.676-72&quot;) false iex&gt; CPF.valid?(&quot;56360667673&quot;) true iex&gt; CPF.valid?(&quot;56360667672&quot;) false"},{"ref":"readme.html#parsing-and-storing-cpfs","title":"CPF - Parsing and Storing CPFs","type":"extras","doc":"If you want to store CPF as integer or as String.t, this library have you covered. You can do: iex&gt; &quot;044.858.476-08&quot; |&gt; CPF.parse!() |&gt; CPF.to_integer() 4485847608 iex&gt; &quot;044.858.476-08&quot; |&gt; CPF.parse!() |&gt; to_string() &quot;04485847608&quot; Storing CPF as strings are easier for a human to read since the 0 padding digits are there. Meanwhile, storing as integers will allow you have better performance in CPF lookups. The CPF.parse/1 and CPF.parse!/1 returns you the CPF value wrapped in a custom type with explicit digits. iex&gt; CPF.parse(&quot;044.858.476-08&quot;) {:ok, #CPF&lt;&quot;044.858.476-08&quot;&gt;} iex&gt; CPF.parse(&quot;044.858.476-07&quot;) {:error, %CPF.ParsingError{reason: :invalid_verifier}} iex&gt; CPF.parse!(&quot;044.858.476-08&quot;) #CPF&lt;&quot;044.858.476-08&quot;&gt; iex&gt; CPF.parse!(&quot;044.858.476-07&quot;) ** (CPF.ParsingError) invalid verifier With the casted CPF in hands, you can use CPF.format/1, CPF.to_integer/1 and to_string/1."},{"ref":"readme.html#cpf-formatting","title":"CPF - CPF Formatting","type":"extras","doc":"If you have a valid CPF strings or integer in hands, you can use CPF.new/1 and in sequence call CPF.format/1: iex&gt; 4485847608 |&gt; CPF.new() |&gt; CPF.format() &quot;044.858.476-08&quot; iex&gt; &quot;04485847608&quot; |&gt; CPF.new() |&gt; CPF.format() &quot;044.858.476-08&quot; The CPF.format/1 expects the input be wrapped in the CPF type. Remember, only use CPF.new with valid CPFs, no other checks are done there. If you need some validation, use CPF.parse/1."},{"ref":"readme.html#why-not-other-libraries","title":"CPF - Why not other libraries?","type":"extras","doc":"This library runs 3 times faster and consume 3 times less memory and work with primitive types, no extra struct is necessary."},{"ref":"readme.html#docs","title":"CPF - Docs","type":"extras","doc":"The docs can be found at https://hexdocs.pm/cpf."}]